@@ -3,7 +3,7 @@
  *		that maintains the host name and the domain name. It
  *		is also used to show the FQDN and the IP-Addresses.
  *
- * Usage:	hostname [-d|-f|-s|-a|-i|-y|-A|-I]
+ * Usage:	hostname [-a|-A|-d|-f|-i|-I|-s|-y]
  *		hostname [-h|-V]
  *		hostname [-b] {name|-F file}
  *		dnsdomainname
@@ -45,7 +45,7 @@
 #include <err.h>
 #include <rpcsvc/ypclnt.h>
 
-#define VERSION "3.10"
+#define VERSION "3.11"
 
 enum type_t { DEFAULT, DNS, FQDN, SHORT, ALIAS, IP, NIS, NIS_DEF, ALL_FQDNS, ALL_IPS };
 
@@ -147,7 +147,7 @@ usage(FILE *stream)
 {
 	fprintf(stream,
 		"Usage: hostname [-v] [-b] {hostname|-F file}         set host name (from file)\n"
-		"       hostname [-v] [-d|-f|-s|-a|-i|-y|-A|-I]             display formatted name\n"
+		"       hostname [-v] [-a|-A|-d|-f|-i|-I|-s|-y]       display formatted name\n"
 		"       hostname [-v]                                 display host name\n"
 		"\n"
 		"       {yp,nis,}domainname [-v] {nisdomain|-F file}  set NIS domain name (from file)\n"
@@ -162,16 +162,16 @@ usage(FILE *stream)
 		"       dnsdomainname=hostname -d\n"
 		"\n"
 		"Program options:\n"
-		"    -s, --short            short host name\n"
 		"    -a, --alias            alias names\n"
+		"    -A, --all-fqdns        all long host names (FQDNs)\n"
+		"    -b, --boot             set default hostname if none available\n"
+		"    -d, --domain           DNS domain name\n"
+		"    -f, --fqdn, --long     long host name (FQDN)\n"
+		"    -F, --file             read host name or NIS domain name from given file\n"
 		"    -i, --ip-address       addresses for the host name\n"
 		"    -I, --all-ip-addresses all addresses for the host\n"
-		"    -f, --fqdn, --long     long host name (FQDN)\n"
-		"    -A, --all-fqdns        all long host names (FQDNs)\n"
-		"    -d, --domain           DNS domain name\n"
+		"    -s, --short            short host name\n"
 		"    -y, --yp, --nis        NIS/YP domain name\n"
-		"    -b, --boot             set default hostname if none available\n"
-		"    -F, --file             read host name or NIS domain name from given file\n"
 		"\n"
 		"Description:\n"
 		"   This command can get or set the host name or the NIS domain name. You can\n"
